@@ -11,23 +11,18 @@ class LoginRequiredMiddleware(object):
     View is also deemed to be Public if listed in in django settings in the
     STRONGHOLD_PUBLIC_URLS dictionary
     each url in STRONGHOLD_PUBLIC_URLS must be a valid regex
+
     """
+
     def __init__(self, *args, **kwargs):
         self.public_view_urls = getattr(conf, 'STRONGHOLD_PUBLIC_URLS', ())
 
     def process_view(self, request, view_func, view_args, view_kwargs):
-        # if request is authenticated, dont process it
-        if request.user.is_authenticated():
+        if request.user.is_authenticated() or utils.is_view_func_public(view_func) \
+                or self.is_public_url(request.path_info):
             return None
 
-        # if its a public view, don't process it
-        is_public = utils.is_view_func_public(view_func)
-        if is_public:
-            return None
-
-        # if this view matches a whitelisted regex, don't process it
-        for view_url in self.public_view_urls:
-            if view_url.match(request.path_info):
-                return None
-
         return login_required(view_func)(request, *view_args, **view_kwargs)
+
+    def is_public_url(self, url):
+        return any(public_url.match(url) for public_url in self.public_view_urls)
